<?php

namespace Drupal\commerce_account_balance\Controller;

use Drupal\commerce_price\Price;
use Drupal\commerce_store\Entity\Store;
use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Session\AccountInterface;
use Drupal\user\UserInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Request;

/**
 * Controller for handling account balance operations.
 */
class AccountBalanceController extends ControllerBase {

  /**
   * The current user service.
   *
   * @var \Drupal\Core\Session\AccountInterface
   */
  protected $currentUser;

  /**
   * Constructs a new AccountBalanceController.
   *
   * @param \Drupal\Core\Session\AccountInterface $current_user
   *   The current user service.
   */
  public function __construct(AccountInterface $current_user) {
    $this->currentUser = $current_user;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('current_user')
    );
  }


  // private function currency() {
  //
  //   $data = [];
  //   $data['store'] = \Drupal::service('commerce_store.current_store')->getStore();
  //   $data['default_currency'] = $data['store']->getDefaultCurrencyCode();
  //   return $data['default_currency'];
  //
  // }


  /**
   * Displays the account balance page.
   *
   * @return array
   *   A render array representing the account balance page.
   */
  public function viewBalance($order) {

    $data = [];

    // Load the full user entity if needed.
    $data['order'] = $order;
    $data['mail'] = $data['order']->get("mail")->value;

    // Get orders related to the same email
    $data['orders'] = getMailOrders($data['mail']);
    $data['email_balance'] = getEmailBalance($data['orders']);

    // Build the render array
    $build = [
      '#theme' => 'commerce_orders_balance_table',
      '#email_balance' => $data['email_balance'],
      // @todo improve polarity
      '#balance_polarity' => 'positive',
      '#empty_message' => t('No orders found.'),
      '#label' => $data['mail'],
      '#orders' => $data['orders'],
    ];

  return $build;

  }

  /**
   * API endpoint to get account balance.
   *
   * @param \Symfony\Component\HttpFoundation\Request $request
   *   The request object.
   *
   * @return \Symfony\Component\HttpFoundation\JsonResponse
   *   JSON response with balance data.
   */
  // public function getBalanceApi(Request $request) {
  //   // Check permissions or implement your authentication logic.
  //   if (!$this->currentUser->isAuthenticated()) {
  //     return new JsonResponse(['error' => 'Access denied'], 403);
  //   }
  //
  //   $user = $this->entityTypeManager()->getStorage('user')->load($this->currentUser->id());
  //   $balance = $this->getUserBalance($user);
  //
  //   return new JsonResponse([
  //     'user_id' => $user->id(),
  //     'balance' => $balance,
  //     'currency' => 'USD', // Adjust
  //     'last_updated' => time(),
  //   ]);
  // }

  /**
   * Helper method to get user balance.
   *
   * @param \Drupal\user\UserInterface $user
   *   The user entity.
   *
   * @return float
   *   The user's balance.
   */
  protected function getUserBalance(UserInterface $user) {
    // Implement the actual balance retrieval logic here.

    // Get from custom field?
    if ($user->hasField('field_account_balance')) {
      return (float) $user->get('field_account_balance')->value ?? 0.00;
    }

    // Default return if no balance field exists.
    return 0.00;
  }

  /**
   * Helper method to get email balance.
   *
   * Get balance for orders related to a given email.
   * @param \Drupal\commerce_order\Entity\Order $order
   *   The order entity.
   *
   * @return float
   *   The email's balance.
   */
  // protected function getEmailBalance(array $orders) {
  //
  //   $data = [];
  //   $data['orders'] = $orders;
  //   $data['email_balance'] = 0.00;
  //   foreach ($data['orders'] as $o) {
  //     // dump ($o);
  //     $data['email_balance'] += (float) $o->get("balance")->number;
  //   }
  //
  //   $price = new Price($data['email_balance'], $this->currency());
  //
  //   $data['email_balance'] = [
  //     '#type' => 'inline_template',
  //     '#template' => '{{ price|commerce_price_format }}',
  //     '#context' => [
  //       'price' => $price,
  //     ],
  //   ];
  //   return $data['email_balance'];
  //
  //   // Get from custom field?
  //   // Future implementation when user will be
  //   // handled
  //   // if ($user->hasField('field_account_balance')) {
  //   //   return (float) $user->get('field_account_balance')->value ?? 0.00;
  //   // }
  //
  // }

// public function getMailOrders($mail) {
//
//     $data = [];
//     $data['mail'] = $mail;
//
//     $data['orderStorage'] = \Drupal::entityTypeManager()->getStorage('commerce_order');
//
//     $data['ids'] = $data['orderStorage']->getQuery()
//       ->condition('mail', $data['mail'])
//       ->accessCheck(TRUE)
//       ->range(0, 500)
//       ->execute();
//     $data['orders'] = $data['orderStorage']->loadMultiple($data['ids']);
//
//     return $data['orders'];
//
// }

/**
   * Displays balance history.
   *
   * @return array
   *   A render array for balance history.
   */
  // public function viewBalanceHistory() {
  //   // Implement balance history logic here.
  //   $build = [
  //     '#theme' => 'account_balance_history',
  //     '#transactions' => [], // Add transaction data here.
  //     '#attached' => [
  //       'library' => ['commerce_account_balance/balance_history'],
  //     ],
  //   ];
  //   return $build;
  // }

}
